.. _swh-journal:

Software Heritage - Journal
===========================

Persistent logger of changes to the archive, with publish-subscribe support.


Reference Documentation
-----------------------

.. toctree::
   :maxdepth: 2

   /apidoc/swh.journal
